provider "aws" {
  region  = var.region
  profile = var.profile
}

module "vpc" {
  source         = "../tfmodule-aws-2tier-vpc"
  region         = var.region
  profile        = var.profile
  vpc-name       = var.vpc-name
  vpc-cidr       = var.vpc-cidr
  vpc-azs        = var.vpc-azs
  enable-private = false
  common-tags = {
    "Owner" = "maguec"
  }
}

module "nodes" {
  source           = "../tfmodule-aws-redis-enterprise"
  region           = var.region
  profile          = var.profile
  open-nets        = ["76.14.80.208/32"]
  data-node-count  = 3
  re-volume-size   = 500
  re-instance-type = "m5.4xlarge"
  vpc-cidr         = var.vpc-cidr
  vpc-azs          = var.vpc-azs
  vpc-name         = var.vpc-name
  vpc-id           = module.vpc.vpc-id
  vpc-subnets      = module.vpc.subnets-public
  enable-flash     = true
  common-tags = {
    "Owner"   = "maguec"
    "Project" = "AWS Testing Environment"
  }
}

module "tmuxer" {
  source  = "../tfmodule-cloud-tmux"
  ssh-key = "${var.vpc-name}.pem"
  user    = "ubuntu"
  nodes   = module.nodes.node-ips
  outpath = "."
}

module "dns-lb" {
  source      = "../tfmodule-aws-dns-lb"
  profile     = var.profile
  region      = var.region
  vpc-subnets = module.vpc.subnets-public
  vpc-id      = module.vpc.vpc-id
  node-ids    = module.nodes.node-ids
  common-tags = {
    "Owner"   = "maguec"
    "Project" = "AWS Testing Environment"
  }
}
